summaryrefslogtreecommitdiffstats
path: root/examples/h5_extlink.c
diff options
context:
space:
mode:
authorDana Robinson <derobins@hdfgroup.org>2020-01-16 21:29:34 (GMT)
committerDana Robinson <derobins@hdfgroup.org>2020-01-16 21:29:34 (GMT)
commita92c735c9b57049e8c4037d3490f7e10f8eef4d6 (patch)
tree74da25151de6d1e32329dfcd62e17c863e2e3de1 /examples/h5_extlink.c
parent024f7ba09250110c19b070c9699cfbc0f9dc2b96 (diff)
downloadhdf5-a92c735c9b57049e8c4037d3490f7e10f8eef4d6.zip
hdf5-a92c735c9b57049e8c4037d3490f7e10f8eef4d6.tar.gz
hdf5-a92c735c9b57049e8c4037d3490f7e10f8eef4d6.tar.bz2
Squashed commit of the token_refactoring branch:
Diffstat (limited to 'examples/h5_extlink.c')
-rw-r--r--examples/h5_extlink.c48
1 files changed, 24 insertions, 24 deletions
diff --git a/examples/h5_extlink.c b/examples/h5_extlink.c
index 229e465..fea1fa2 100644
--- a/examples/h5_extlink.c
+++ b/examples/h5_extlink.c
@@ -316,7 +316,7 @@ static void hard_link_example(void)
{
hid_t file_id;
hid_t group_id;
- H5L_info_t li;
+ H5L_info2_t li;
/* Define the link class that we'll use to register "user-defined hard
* links" using the callbacks we defined above.
* A link class can have NULL for any callback except its traverse
@@ -361,13 +361,13 @@ static void hard_link_example(void)
* the target group's address. We do this by calling H5Lget_info
* on a hard link to the object.
*/
- H5Lget_info(file_id, TARGET_GROUP, &li, H5P_DEFAULT);
+ H5Lget_info2(file_id, TARGET_GROUP, &li, H5P_DEFAULT);
/* Now create a user-defined link. We give it the group's address
* as its udata.
*/
- H5Lcreate_ud(file_id, UD_HARD_LINK_NAME, (H5L_type_t)UD_HARD_CLASS, &(li.u.address),
- sizeof(li.u.address), H5P_DEFAULT, H5P_DEFAULT);
+ H5Lcreate_ud(file_id, UD_HARD_LINK_NAME, (H5L_type_t)UD_HARD_CLASS, &(li.u.token),
+ sizeof(H5O_token_t), H5P_DEFAULT, H5P_DEFAULT);
/* The UD hard link has now incremented the group's reference count
* like a normal hard link would. This means that we can unlink the
@@ -404,23 +404,23 @@ static void hard_link_example(void)
static herr_t UD_hard_create(const char *link_name, hid_t loc_group,
const void *udata, size_t udata_size, hid_t lcpl_id)
{
- haddr_t addr;
- hid_t target_obj = -1;
+ H5O_token_t token;
+ hid_t target_obj = H5I_INVALID_HID;
herr_t ret_value = 0;
/* Make sure that the address passed in looks valid */
- if(udata_size != sizeof(haddr_t))
+ if(udata_size != sizeof(H5O_token_t))
{
ret_value = -1;
goto done;
}
- addr = *((const haddr_t *) udata);
+ token = *((H5O_token_t *) udata);
/* Open the object this link points to so that we can increment
* its reference count. This also ensures that the address passed
* in points to a real object (although this check is not perfect!) */
- target_obj= H5Oopen_by_addr(loc_group, addr);
+ target_obj = H5Oopen_by_token(loc_group, token);
if(target_obj < 0)
{
ret_value = -1;
@@ -448,23 +448,23 @@ done:
static herr_t UD_hard_delete(const char *link_name, hid_t loc_group,
const void *udata, size_t udata_size)
{
- haddr_t addr;
- hid_t target_obj = -1;
+ H5O_token_t token;
+ hid_t target_obj = H5I_INVALID_HID;
herr_t ret_value = 0;
/* Sanity check; we have already verified the udata's size in the creation
* callback.
*/
- if(udata_size != sizeof(haddr_t))
+ if(udata_size != sizeof(H5O_token_t))
{
ret_value = -1;
goto done;
}
- addr = *((const haddr_t *) udata);
+ token = *((H5O_token_t *) udata);
/* Open the object this link points to */
- target_obj= H5Oopen_by_addr(loc_group, addr);
+ target_obj = H5Oopen_by_token(loc_group, token);
if(target_obj < 0)
{
ret_value = -1;
@@ -492,21 +492,21 @@ done:
static hid_t UD_hard_traverse(const char *link_name, hid_t cur_group,
const void *udata, size_t udata_size, hid_t lapl_id, hid_t dxpl_id)
{
- haddr_t addr;
- hid_t ret_value = -1;
+ H5O_token_t token;
+ hid_t ret_value = H5I_INVALID_HID;
/* Sanity check; we have already verified the udata's size in the creation
* callback.
*/
- if(udata_size != sizeof(haddr_t))
- return -1;
+ if(udata_size != sizeof(H5O_token_t))
+ return H5I_INVALID_HID;
- addr = *((const haddr_t *) udata);
+ token = *((H5O_token_t *) udata);
- /* Open the object by address. If H5Oopen_by_addr fails, ret_value will
+ /* Open the object by token. If H5Oopen_by_token fails, ret_value will
* be negative to indicate that the traversal function failed.
*/
- ret_value = H5Oopen_by_addr(cur_group, addr);
+ ret_value = H5Oopen_by_token(cur_group, token);
return ret_value;
}
@@ -621,7 +621,7 @@ static hid_t UD_plist_traverse(const char *link_name, hid_t cur_group,
const void *udata, size_t udata_size, hid_t lapl_id, hid_t dxpl_id)
{
char * path;
- hid_t ret_value = -1;
+ hid_t ret_value = H5I_INVALID_HID;
/* If the link property isn't set or can't be found, traversal fails. */
if(H5Pexist(lapl_id, PLIST_LINK_PROP) < 0)
@@ -638,7 +638,7 @@ static hid_t UD_plist_traverse(const char *link_name, hid_t cur_group,
return ret_value;
error:
- return -1;
+ return H5I_INVALID_HID;
}
@@ -404,23 +404,23 @@ static void hard_link_example(void)
/* Open the object this link points to so that we can increment
- * its reference count. This also ensures that the address passed
+ * its reference count. This also ensures that the token passed
* in points to a real object (although this check is not perfect!) */